@@ -22,8 +22,8 @@ import weakref
 import time
 
 import telepathy
-import pymsn
-import pymsn.event
+import papyon
+import papyon.event
 
 from butterfly.util.decorator import async
 from butterfly.handle import ButterflyHandleFactory
@@ -37,17 +37,17 @@ class ButterflyTextChannel(
         telepathy.server.ChannelTypeText,
         telepathy.server.ChannelInterfaceGroup,
         telepathy.server.ChannelInterfaceChatState,
-        pymsn.event.ConversationEventInterface):
+        papyon.event.ConversationEventInterface):
 
-    def __init__(self, connection, conversation):
+    def __init__(self, conn, manager, conversation, props):
         self._recv_id = 0
         self._conversation = conversation
-        self._conn_ref = weakref.ref(connection)
+        self._conn_ref = weakref.ref(conn)
 
-        telepathy.server.ChannelTypeText.__init__(self, connection, None)
+        telepathy.server.ChannelTypeText.__init__(self, conn, manager, props)
         telepathy.server.ChannelInterfaceGroup.__init__(self)
         telepathy.server.ChannelInterfaceChatState.__init__(self)
-        pymsn.event.ConversationEventInterface.__init__(self, self._conversation)
+        papyon.event.ConversationEventInterface.__init__(self, self._conversation)
 
         self.GroupFlagsChanged(telepathy.CHANNEL_GROUP_FLAG_CAN_ADD, 0)
         self.__add_initial_participants()
@@ -60,7 +60,7 @@ class ButterflyTextChannel(
 
     def Send(self, message_type, text):
         if message_type == telepathy.CHANNEL_TEXT_MESSAGE_TYPE_NORMAL:
-            self._conversation.send_text_message(pymsn.ConversationMessage(text))
+            self._conversation.send_text_message(papyon.ConversationMessage(text))
         elif message_type == telepathy.CHANNEL_TEXT_MESSAGE_TYPE_ACTION and \
                 text == u"nudge":
             self._conversation.send_nudge()
@@ -73,33 +73,38 @@ class ButterflyTextChannel(
         telepathy.server.ChannelTypeText.Close(self)
         self.remove_from_connection()
 
-    # pymsn.event.ConversationEventInterface
+    # Redefine GetSelfHandle since we use our own handle
+    #  as Butterfly doesn't have channel specific handles
+    def GetSelfHandle(self):
+        return self._conn.GetSelfHandle()
+
+    # papyon.event.ConversationEventInterface
     def on_conversation_user_joined(self, contact):
         handle = ButterflyHandleFactory(self._conn_ref(), 'contact',
                 contact.account, contact.network_id)
-        logger.info("User %r joined" % handle)
+        logger.info("User %s joined" % unicode(handle))
         self.MembersChanged('', [handle], [], [], [],
                 handle, telepathy.CHANNEL_GROUP_CHANGE_REASON_INVITED)
 
-    # pymsn.event.ConversationEventInterface
+    # papyon.event.ConversationEventInterface
     def on_conversation_user_left(self, contact):
         handle = ButterflyHandleFactory(self._conn_ref(), 'contact',
                 contact.account, contact.network_id)
-        logger.info("User %r left" % handle)
+        logger.info("User %s left" % unicode(handle))
         if len(self._members) == 1:
             self.ChatStateChanged(handle, telepathy.CHANNEL_CHAT_STATE_GONE)
         else:
             self.MembersChanged('', [], [handle], [], [],
                     handle, telepathy.CHANNEL_GROUP_CHANGE_REASON_NONE)
 
-    # pymsn.event.ConversationEventInterface
+    # papyon.event.ConversationEventInterface
     def on_conversation_user_typing(self, contact):
         handle = ButterflyHandleFactory(self._conn_ref(), 'contact',
                 contact.account, contact.network_id)
-        logger.info("User %r is typing" % handle)
+        logger.info("User %s is typing" % unicode(handle))
         self.ChatStateChanged(handle, telepathy.CHANNEL_CHAT_STATE_COMPOSING)
 
-    # pymsn.event.ConversationEventInterface
+    # papyon.event.ConversationEventInterface
     def on_conversation_message_received(self, sender, message):
         id = self._recv_id
         timestamp = int(time.time())
@@ -107,25 +112,26 @@ class ButterflyTextChannel(
                 sender.account, sender.network_id)
         type = telepathy.CHANNEL_TEXT_MESSAGE_TYPE_NORMAL
         message = message.content
-        logger.info("User %r sent a message" % handle)
+        logger.info("User %s sent a message" % unicode(handle))
         self.Received(id, timestamp, handle, type, 0, message)
         self._recv_id += 1
 
-    # pymsn.event.ConversationEventInterface
+    # papyon.event.ConversationEventInterface
     def on_conversation_nudge_received(self, sender):
         id = self._recv_id
         timestamp = int(time.time())
         handle = ButterflyHandleFactory(self._conn_ref(), 'contact',
                 sender.account, sender.network_id)
         type = telepathy.CHANNEL_TEXT_MESSAGE_TYPE_ACTION
-        text = unicode(_("sends you a nudge"), "utf-8")
-        logger.info("User %r sent a nudge" % handle)
+        text = unicode("sends you a nudge", "utf-8")
+        logger.info("User %s sent a nudge" % unicode(handle))
         self.Received(id, timestamp, handle, type, 0, text)
         self._recv_id += 1
 
     @async
     def __add_initial_participants(self):
         handles = []
+        handles.append(self._conn.GetSelfHandle())
         for participant in self._conversation.participants:
             handle = ButterflyHandleFactory(self._conn_ref(), 'contact',
                     participant.account, participant.network_id)
