@@ -29,6 +29,7 @@ from butterfly.presence import ButterflyPresence
 from butterfly.aliasing import ButterflyAliasing
 from butterfly.avatars import ButterflyAvatars
 from butterfly.handle import ButterflyHandleFactory
+from butterfly.capabilities import ButterflyCapabilities
 from butterfly.contacts import ButterflyContacts
 from butterfly.channel_manager import ButterflyChannelManager
 
@@ -42,6 +43,7 @@ class ButterflyConnection(telepathy.server.Connection,
         ButterflyPresence,
         ButterflyAliasing,
         ButterflyAvatars,
+        ButterflyCapabilities,
         ButterflyContacts,
         papyon.event.ClientEventInterface,
         papyon.event.InviteEventInterface):
@@ -95,6 +97,7 @@ class ButterflyConnection(telepathy.server.Connection,
             ButterflyPresence.__init__(self)
             ButterflyAliasing.__init__(self)
             ButterflyAvatars.__init__(self)
+            ButterflyCapabilities.__init__(self)
             ButterflyContacts.__init__(self)
             papyon.event.ClientEventInterface.__init__(self, self._msn_client)
             papyon.event.InviteEventInterface.__init__(self, self._msn_client)
@@ -139,7 +142,6 @@ class ButterflyConnection(telepathy.server.Connection,
 
         handles = []
         for name in names:
-            name = name.encode('utf-8')
             if handle_type == telepathy.HANDLE_TYPE_CONTACT:
                 name = name.rsplit('#', 1)
                 contact_name = name[0]
@@ -227,7 +229,8 @@ class ButterflyConnection(telepathy.server.Connection,
             #self._channel_manager.channel_for_props(props, signal=True)
 
             for group in self.msn_client.address_book.groups:
-                handle = ButterflyHandleFactory(self, 'group', group.name)
+                handle = ButterflyHandleFactory(self, 'group',
+                        group.name.decode("utf-8"))
                 props = self._generate_props(
                     telepathy.CHANNEL_TYPE_CONTACT_LIST, handle, False)
                 self._channel_manager.channel_for_props(props, signal=True)
@@ -240,6 +243,7 @@ class ButterflyConnection(telepathy.server.Connection,
                 self._client.profile.presence = presence
             if message is not None:
                 self._client.profile.personal_message = message
+            self._client.profile.end_point_name = "PAPYON"
 
             if (presence is not None) or (message is not None):
                 self._presence_changed(ButterflyHandleFactory(self, 'self'),
@@ -280,6 +284,29 @@ class ButterflyConnection(telepathy.server.Connection,
         channel = self._channel_manager.channel_for_props(props,
             signal=True, conversation=conversation)
 
+    # papyon.event.InviteEventInterface
+    def on_invite_conference(self, call):
+        logger.debug("Call invite")
+        handle = ButterflyHandleFactory(self, 'contact', call.peer.account,
+                call.peer.network_id)
+
+        props = self._generate_props(telepathy.CHANNEL_TYPE_STREAMED_MEDIA,
+                handle, False)
+        channel = self._channel_manager.channel_for_props(props,
+                signal=True, call=call)
+
+    # papyon.event.InviteEventInterface
+    def on_invite_webcam(self, session, producer):
+        direction = (producer and "send") or "receive"
+        logger.debug("Invitation to %s webcam" % direction)
+
+        handle = ButterflyHandleFactory(self, 'contact', session.peer.account,
+                session.peer.network_id)
+        props = self._generate_props(telepathy.CHANNEL_TYPE_STREAMED_MEDIA,
+                handle, False)
+        channel = self._channel_manager.channel_for_props(props, signal=True,
+                call=session)
+
     def _advertise_disconnected(self):
         self._manager.disconnected(self)
 
